# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb.application
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdb.application import CopyTableOperation as CopyTableOperation
    if hasattr(CopyTableOperation, '_constants') and isinstance(CopyTableOperation._constants, dict):
        CopyTableOperation._constants['__ooo_ns__'] = 'com.sun.star.sdb.application'
        CopyTableOperation._constants['__ooo_full_ns__'] = 'com.sun.star.sdb.application.CopyTableOperation'
        CopyTableOperation._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global CopyTableOperationEnum
        ls = [f for f in dir(CopyTableOperation) if not callable(getattr(CopyTableOperation, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(CopyTableOperation, name)
        CopyTableOperationEnum = IntEnum('CopyTableOperationEnum', _dict)
    build_enum()
else:
    from ....lo.sdb.application.copy_table_operation import CopyTableOperation as CopyTableOperation

    class CopyTableOperationEnum(IntEnum):
        """
        Enum of Const Class CopyTableOperation

        specifies the different basic operations a CopyTableWizard can do.
        
        **since**
        
            OOo 2.4
        """
        CopyDefinitionAndData = CopyTableOperation.CopyDefinitionAndData
        """
        specifies that the wizard should copy the source table to the target database, by creating a new table and copying all data.
        """
        CopyDefinitionOnly = CopyTableOperation.CopyDefinitionOnly
        """
        specifies that the wizard should copy the source table to the target database, by only creating a new table with the same structure as the source table.
        """
        CreateAsView = CopyTableOperation.CreateAsView
        """
        specifies the wizard should create the source table as view
        
        This option is not available if the target database does not support views.
        """
        AppendData = CopyTableOperation.AppendData
        """
        specifies the wizard should append the source table's data to an existing table in the target database.
        """

__all__ = ['CopyTableOperation', 'CopyTableOperationEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.ui import ImageType as ImageType
    if hasattr(ImageType, '_constants') and isinstance(ImageType._constants, dict):
        ImageType._constants['__ooo_ns__'] = 'com.sun.star.ui'
        ImageType._constants['__ooo_full_ns__'] = 'com.sun.star.ui.ImageType'
        ImageType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ImageTypeEnum
        ls = [f for f in dir(ImageType) if not callable(getattr(ImageType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ImageType, name)
        ImageTypeEnum = IntFlag('ImageTypeEnum', _dict)
    build_enum()
else:
    from ...lo.ui.image_type import ImageType as ImageType

    class ImageTypeEnum(IntFlag):
        """
        Enum of Const Class ImageType

        Determine the image set of an image manager.
        
        The constants describe bits in a bit field which determine the current image set of an image manager.
        
        **since**
        
            OOo 2.0
        """
        SIZE_DEFAULT = ImageType.SIZE_DEFAULT
        """
        an image with default size.
        """
        SIZE_LARGE = ImageType.SIZE_LARGE
        """
        an image with large size.
        """
        SIZE_32 = ImageType.SIZE_32
        """
        an image with size 32.
        
        **since**
        
            LibreOffice 5.3
        """
        COLOR_NORMAL = ImageType.COLOR_NORMAL
        """
        an image with normal colors.
        """
        COLOR_HIGHCONTRAST = ImageType.COLOR_HIGHCONTRAST
        """
        an image with high contrast colors.
        """

__all__ = ['ImageType', 'ImageTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml.crypto
# Libre Office Version: 7.3
from enum import Enum


class SecurityOperationStatus(Enum):
    """
    Enum Class

    

    See Also:
        `API SecurityOperationStatus <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dc>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.crypto'
    __ooo_full_ns__: str = 'com.sun.star.xml.crypto.SecurityOperationStatus'
    __ooo_type_name__: str = 'enum'

    ASSERTION = 'ASSERTION'
    """
    """
    CERT_HAS_EXPIRED = 'CERT_HAS_EXPIRED'
    """
    """
    CERT_ISSUER_FAILED = 'CERT_ISSUER_FAILED'
    """
    """
    CERT_NOT_FOUND = 'CERT_NOT_FOUND'
    """
    """
    CERT_NOT_YET_VALID = 'CERT_NOT_YET_VALID'
    """
    """
    CERT_REVOKED = 'CERT_REVOKED'
    """
    """
    CERT_VERIFY_FAILED = 'CERT_VERIFY_FAILED'
    """
    """
    CRYPTO_FAILED = 'CRYPTO_FAILED'
    """
    """
    DATA_NOT_MATCH = 'DATA_NOT_MATCH'
    """
    """
    DISABLED = 'DISABLED'
    """
    """
    DSIG_INVALID_REFERENCE = 'DSIG_INVALID_REFERENCE'
    """
    """
    DSIG_NO_REFERENCES = 'DSIG_NO_REFERENCES'
    """
    """
    ENGINE_FAILED = 'ENGINE_FAILED'
    """
    The following constants are derived from XMLSec error definitions, as following:
    
    XMLSEC_ERRORS_R_XMLSEC_FAILED XMLSEC_ERRORS_R_MALLOC_FAILED XMLSEC_ERRORS_R_STRDUP_FAILED XMLSEC_ERRORS_R_CRYPTO_FAILED XMLSEC_ERRORS_R_XML_FAILED XMLSEC_ERRORS_R_XSLT_FAILED XMLSEC_ERRORS_R_IO_FAILED XMLSEC_ERRORS_R_DISABLED XMLSEC_ERRORS_R_NOT_IMPLEMENTED XMLSEC_ERRORS_R_INVALID_SIZE XMLSEC_ERRORS_R_INVALID_DATA XMLSEC_ERRORS_R_INVALID_RESULT XMLSEC_ERRORS_R_INVALID_TYPE XMLSEC_ERRORS_R_INVALID_OPERATION XMLSEC_ERRORS_R_INVALID_STATUS XMLSEC_ERRORS_R_INVALID_FORMAT XMLSEC_ERRORS_R_DATA_NOT_MATCH XMLSEC_ERRORS_R_INVALID_NODE XMLSEC_ERRORS_R_INVALID_NODE_CONTENT XMLSEC_ERRORS_R_INVALID_NODE_ATTRIBUTE XMLSEC_ERRORS_R_MISSING_NODE_ATTRIBUTE XMLSEC_ERRORS_R_NODE_ALREADY_PRESENT XMLSEC_ERRORS_R_UNEXPECTED_NODE XMLSEC_ERRORS_R_NODE_NOT_FOUND XMLSEC_ERRORS_R_INVALID_TRANSFORM XMLSEC_ERRORS_R_INVALID_TRANSFORM_KEY XMLSEC_ERRORS_R_INVALID_URI_TYPE XMLSEC_ERRORS_R_TRANSFORM_SAME_DOCUMENT_REQUIRED XMLSEC_ERRORS_R_TRANSFORM_DISABLED XMLSEC_ERRORS_R_INVALID_KEY_DATA XMLSEC_ERRORS_R_KEY_DATA_NOT_FOUND XMLSEC_ERRORS_R_KEY_DATA_ALREADY_EXIST XMLSEC_ERRORS_R_INVALID_KEY_DATA_SIZE XMLSEC_ERRORS_R_KEY_NOT_FOUND XMLSEC_ERRORS_R_KEYDATA_DISABLED XMLSEC_ERRORS_R_MAX_RETRIEVALS_LEVEL XMLSEC_ERRORS_R_MAX_RETRIEVAL_TYPE_MISMATCH XMLSEC_ERRORS_R_MAX_ENCKEY_LEVEL XMLSEC_ERRORS_R_CERT_VERIFY_FAILED XMLSEC_ERRORS_R_CERT_NOT_FOUND XMLSEC_ERRORS_R_CERT_REVOKED XMLSEC_ERRORS_R_CERT_ISSUER_FAILED XMLSEC_ERRORS_R_CERT_NOT_YET_VALID XMLSEC_ERRORS_R_CERT_HAS_EXPIRED XMLSEC_ERRORS_R_DSIG_NO_REFERENCES XMLSEC_ERRORS_R_DSIG_INVALID_REFERENCE XMLSEC_ERRORS_R_ASSERTION XMLSEC_ERRORS_MAX_NUMBER
    """
    INVALID_DATA = 'INVALID_DATA'
    """
    """
    INVALID_FORMAT = 'INVALID_FORMAT'
    """
    """
    INVALID_KEY_DATA = 'INVALID_KEY_DATA'
    """
    """
    INVALID_KEY_DATA_SIZE = 'INVALID_KEY_DATA_SIZE'
    """
    """
    INVALID_NODE = 'INVALID_NODE'
    """
    """
    INVALID_NODE_ATTRIBUTE = 'INVALID_NODE_ATTRIBUTE'
    """
    """
    INVALID_NODE_CONTENT = 'INVALID_NODE_CONTENT'
    """
    """
    INVALID_OPERATION = 'INVALID_OPERATION'
    """
    """
    INVALID_RESULT = 'INVALID_RESULT'
    """
    """
    INVALID_SIZE = 'INVALID_SIZE'
    """
    """
    INVALID_STATUS = 'INVALID_STATUS'
    """
    """
    INVALID_TRANSFORM = 'INVALID_TRANSFORM'
    """
    """
    INVALID_TRANSFORM_KEY = 'INVALID_TRANSFORM_KEY'
    """
    """
    INVALID_TYPE = 'INVALID_TYPE'
    """
    """
    INVALID_URI_TYPE = 'INVALID_URI_TYPE'
    """
    """
    IO_FAILED = 'IO_FAILED'
    """
    """
    KEYDATA_DISABLED = 'KEYDATA_DISABLED'
    """
    """
    KEY_DATA_ALREADY_EXIST = 'KEY_DATA_ALREADY_EXIST'
    """
    """
    KEY_DATA_NOT_FOUND = 'KEY_DATA_NOT_FOUND'
    """
    """
    KEY_NOT_FOUND = 'KEY_NOT_FOUND'
    """
    """
    MALLOC_FAILED = 'MALLOC_FAILED'
    """
    """
    MAX_ENCKEY_LEVEL = 'MAX_ENCKEY_LEVEL'
    """
    """
    MAX_RETRIEVALS_LEVEL = 'MAX_RETRIEVALS_LEVEL'
    """
    """
    MAX_RETRIEVAL_TYPE_MISMATCH = 'MAX_RETRIEVAL_TYPE_MISMATCH'
    """
    """
    MISSING_NODE_ATTRIBUTE = 'MISSING_NODE_ATTRIBUTE'
    """
    """
    NODE_ALREADY_PRESENT = 'NODE_ALREADY_PRESENT'
    """
    """
    NODE_NOT_FOUND = 'NODE_NOT_FOUND'
    """
    """
    NOT_IMPLEMENTED = 'NOT_IMPLEMENTED'
    """
    """
    OPERATION_SUCCEEDED = 'OPERATION_SUCCEEDED'
    """
    """
    RUNTIMEERROR_FAILED = 'RUNTIMEERROR_FAILED'
    """
    """
    STRDUP_FAILED = 'STRDUP_FAILED'
    """
    """
    TRANSFORM_DISABLED = 'TRANSFORM_DISABLED'
    """
    """
    TRANSFORM_SAME_DOCUMENT_REQUIRED = 'TRANSFORM_SAME_DOCUMENT_REQUIRED'
    """
    """
    UNEXPECTED_NODE = 'UNEXPECTED_NODE'
    """
    """
    UNKNOWN = 'UNKNOWN'
    """
    """
    XML_FAILED = 'XML_FAILED'
    """
    """
    XSLT_FAILED = 'XSLT_FAILED'
    """
    """

__all__ = ['SecurityOperationStatus']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.binding
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XValueBinding(XInterface_8f010a43):
    """
    specifies a binding to a value which can be read and written.

    See Also:
        `API XValueBinding <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XValueBinding.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.XValueBinding'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.binding.XValueBinding'

    @abstractmethod
    def getSupportedValueTypes(self) -> 'typing.Tuple[object, ...]':
        """
        determines the types which are supported by this binding for value exchange
        """
    @abstractmethod
    def getValue(self, aType: object) -> object:
        """
        retrieves the current value

        Raises:
            IncompatibleTypesException: ``IncompatibleTypesException``
        """
    @abstractmethod
    def setValue(self, aValue: object) -> None:
        """
        sets the current value

        Raises:
            IncompatibleTypesException: ``IncompatibleTypesException``
            InvalidBindingStateException: ``InvalidBindingStateException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
    @abstractmethod
    def supportsType(self, aType: object) -> bool:
        """
        determines whether a given type is supported by this binding for value exchange
        
        Calling this method is equal to calling getSupportedValueTypes(), and looking up the given type in the resulting type sequence.
        """

__all__ = ['XValueBinding']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.inspection
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.inspection import PropertyLineElement as PropertyLineElement
    if hasattr(PropertyLineElement, '_constants') and isinstance(PropertyLineElement._constants, dict):
        PropertyLineElement._constants['__ooo_ns__'] = 'com.sun.star.inspection'
        PropertyLineElement._constants['__ooo_full_ns__'] = 'com.sun.star.inspection.PropertyLineElement'
        PropertyLineElement._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global PropertyLineElementEnum
        ls = [f for f in dir(PropertyLineElement) if not callable(getattr(PropertyLineElement, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(PropertyLineElement, name)
        PropertyLineElementEnum = IntEnum('PropertyLineElementEnum', _dict)
    build_enum()
else:
    from ...lo.inspection.property_line_element import PropertyLineElement as PropertyLineElement

    class PropertyLineElementEnum(IntEnum):
        """
        Enum of Const Class PropertyLineElement

        describes elements of a single line in an object inspector, used to represent a single property
        
        **since**
        
            OOo 2.0.3
        """
        InputControl = PropertyLineElement.InputControl
        """
        specifies the input control in a group of controls related to a single property
        """
        PrimaryButton = PropertyLineElement.PrimaryButton
        """
        specifies the primary button (if present) in a group of controls related to a single property
        """
        SecondaryButton = PropertyLineElement.SecondaryButton
        """
        specifies the secondary button (if present) in a group of controls related to a single property
        """
        All = PropertyLineElement.All
        """
        specifies all elements
        """

__all__ = ['PropertyLineElement', 'PropertyLineElementEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.beans
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .property_change_event import PropertyChangeEvent as PropertyChangeEvent_1b180ebe

class XVetoableChangeListener(XEventListener_c7230c4a):
    """
    is used to receive PropertyChangeEvents whenever a \"constrained\" property is changed.
    
    You can register an XVetoableChangeListener with a source object so as to be notified of any constrained property updates.

    See Also:
        `API XVetoableChangeListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XVetoableChangeListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XVetoableChangeListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XVetoableChangeListener'

    @abstractmethod
    def vetoableChange(self, aEvent: 'PropertyChangeEvent_1b180ebe') -> None:
        """
        gets called when a constrained property is changed.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
        """

__all__ = ['XVetoableChangeListener']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
import typing
from abc import abstractmethod
from .x_configuration_controller import XConfigurationController as XConfigurationController_557c15c4
if typing.TYPE_CHECKING:
    from ...frame.x_controller import XController as XController_b00e0b8f

class ConfigurationController(XConfigurationController_557c15c4):
    """
    Service Class

    See XConfigurationController for a description of the configuration controller.
    
    This service is used at the moment by the XControllerManager to create a configuration controller. This allows developers to replace the default implementation of the configuration controller with their own. This may not be a useful feature. Furthermore the sub controllers may need a tighter coupling than the interfaces allow. These are reasons for removing this service in the future and let the controller manager create the sub controllers directly.

    See Also:
        `API ConfigurationController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1ConfigurationController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.ConfigurationController'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xController: 'XController_b00e0b8f') -> None:
        """
        """


__all__ = ['ConfigurationController']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing


class EnhancedCustomShapeSegmentCommand(object):
    """
    Const Class


    See Also:
        `API EnhancedCustomShapeSegmentCommand <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeSegmentCommand'
    __ooo_type_name__: str = 'const'

    UNKNOWN = 0
    MOVETO = 1
    LINETO = 2
    CURVETO = 3
    CLOSESUBPATH = 4
    ENDSUBPATH = 5
    NOFILL = 6
    NOSTROKE = 7
    ANGLEELLIPSETO = 8
    ANGLEELLIPSE = 9
    ARCTO = 10
    ARC = 11
    CLOCKWISEARCTO = 12
    CLOCKWISEARC = 13
    ELLIPTICALQUADRANTX = 14
    ELLIPTICALQUADRANTY = 15
    QUADRATICCURVETO = 16
    ARCANGLETO = 17
    DARKEN = 18
    """
    darken fill color
    """
    DARKENLESS = 19
    """
    darken fill color less
    """
    LIGHTEN = 20
    """
    lighten fill color
    """
    LIGHTENLESS = 21
    """
    lighten fill color less
    """

__all__ = ['EnhancedCustomShapeSegmentCommand']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
import typing
from abc import abstractmethod
from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XCompoundTypeDescription(XTypeDescription_3c210fb1):
    """
    Reflects a compound type, i.e.
    
    a struct or exception.
    
    For struct types, this type is superseded by XStructTypeDescription, which supports polymorphic struct types.

    See Also:
        `API XCompoundTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XCompoundTypeDescription.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XCompoundTypeDescription'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XCompoundTypeDescription'

    @abstractmethod
    def getBaseType(self) -> 'XTypeDescription_3c210fb1':
        """
        Returns the type of the base type of the compound type.
        
        If the compound does not have a base type, the method returns a null interface.
        """
    @abstractmethod
    def getMemberNames(self) -> 'typing.Tuple[str, ...]':
        """
        Returns the member names of the struct/exception in IDL declaration order.
        """
    @abstractmethod
    def getMemberTypes(self) -> 'typing.Tuple[XTypeDescription_3c210fb1, ...]':
        """
        Returns the member types of the struct/exception in IDL declaration order.
        
        For a polymorphic struct type template, a member of parameterized type is represented by an instance of com.sun.star.reflection.XTypeDescription whose type class is UNKNOWN and whose name is the name of the type parameter.
        """

__all__ = ['XCompoundTypeDescription']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbc import ProcedureResult as ProcedureResult
    if hasattr(ProcedureResult, '_constants') and isinstance(ProcedureResult._constants, dict):
        ProcedureResult._constants['__ooo_ns__'] = 'com.sun.star.sdbc'
        ProcedureResult._constants['__ooo_full_ns__'] = 'com.sun.star.sdbc.ProcedureResult'
        ProcedureResult._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ProcedureResultEnum
        ls = [f for f in dir(ProcedureResult) if not callable(getattr(ProcedureResult, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ProcedureResult, name)
        ProcedureResultEnum = IntEnum('ProcedureResultEnum', _dict)
    build_enum()
else:
    from ...lo.sdbc.procedure_result import ProcedureResult as ProcedureResult

    class ProcedureResultEnum(IntEnum):
        """
        Enum of Const Class ProcedureResult

        determines whether a procedure returns a result or not.
        """
        UNKNOWN = ProcedureResult.UNKNOWN
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that it is not known whether the procedure returns a result.
        """
        NONE = ProcedureResult.NONE
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that the procedure does not return a result.
        """
        RETURN = ProcedureResult.RETURN
        """
        A possible value for column PROCEDURE_TYPE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getProcedures().
        
        Indicates that the procedure returns a result.
        """

__all__ = ['ProcedureResult', 'ProcedureResultEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.datatransfer.clipboard
from .x_clipboard_ex import XClipboardEx as XClipboardEx_c626128a
from .x_clipboard_notifier import XClipboardNotifier as XClipboardNotifier_3e4e150d
from .x_flushable_clipboard import XFlushableClipboard as XFlushableClipboard_53ae1563
from ...lang.x_component import XComponent as XComponent_98dc0ab5

class XSystemClipboard(XClipboardEx_c626128a, XClipboardNotifier_3e4e150d, XFlushableClipboard_53ae1563, XComponent_98dc0ab5):
    """
    Provides a unified interface for new-style service SystemClipboard.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XSystemClipboard <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XSystemClipboard.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.clipboard'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.clipboard.XSystemClipboard'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.clipboard.XSystemClipboard'


__all__ = ['XSystemClipboard']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...lo.xforms.binding import Binding as Binding
from ...lo.xforms.invalid_data_on_submit_exception import InvalidDataOnSubmitException as InvalidDataOnSubmitException
from ...lo.xforms.model import Model as Model
from ...lo.xforms.x_data_type_repository import XDataTypeRepository as XDataTypeRepository
from ...lo.xforms.x_forms import XForms as XForms
from ...lo.xforms.x_forms_event import XFormsEvent as XFormsEvent
from ...lo.xforms.x_forms_supplier import XFormsSupplier as XFormsSupplier
from ...lo.xforms.x_forms_ui_helper1 import XFormsUIHelper1 as XFormsUIHelper1
from ...lo.xforms.x_model import XModel as XModel
from ...lo.xforms.x_model2 import XModel2 as XModel2
from ...lo.xforms.x_submission import XSubmission as XSubmission



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .sax.x_fast_parser import XFastParser as XFastParser_c6ba0c26

class XImportFilter2(XInterface_8f010a43):
    """
    interface to implement for an XML-based import filter.
    
    Enhanced vs XImportFilter to take a XFastDocumentHandler.
    
    **since**
    
        LibreOffice 7.1

    See Also:
        `API XImportFilter2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1XImportFilter2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.XImportFilter2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.XImportFilter2'

    @abstractmethod
    def importer(self, aSourceData: 'typing.Tuple[PropertyValue_c9610c73, ...]', xFastParser: 'XFastParser_c6ba0c26', msUserData: 'typing.Tuple[str, ...]') -> bool:
        """
        performs the import.
        
        The source data (location indicated by aSourceData), and the XML representation of the document must be generated by calls to xocHandler (???) methods.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """

__all__ = ['XImportFilter2']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdbc
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.sdbc import ResultSetType as ResultSetType
    if hasattr(ResultSetType, '_constants') and isinstance(ResultSetType._constants, dict):
        ResultSetType._constants['__ooo_ns__'] = 'com.sun.star.sdbc'
        ResultSetType._constants['__ooo_full_ns__'] = 'com.sun.star.sdbc.ResultSetType'
        ResultSetType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ResultSetTypeEnum
        ls = [f for f in dir(ResultSetType) if not callable(getattr(ResultSetType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ResultSetType, name)
        ResultSetTypeEnum = IntEnum('ResultSetTypeEnum', _dict)
    build_enum()
else:
    from ...lo.sdbc.result_set_type import ResultSetType as ResultSetType

    class ResultSetTypeEnum(IntEnum):
        """
        Enum of Const Class ResultSetType

        describes the different scroll capabilities of a result set.
        """
        FORWARD_ONLY = ResultSetType.FORWARD_ONLY
        """
        is the type for a com.sun.star.sdb.ResultSet object whose cursor may move only forward.
        """
        SCROLL_INSENSITIVE = ResultSetType.SCROLL_INSENSITIVE
        """
        is the type for a com.sun.star.sdb.ResultSet object that is scrollable but generally not sensitive to changes made by others.
        """
        SCROLL_SENSITIVE = ResultSetType.SCROLL_SENSITIVE
        """
        is the type for a com.sun.star.sdb.ResultSet object that is scrollable and generally sensitive to changes made by others.
        """

__all__ = ['ResultSetType', 'ResultSetTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from enum import Enum


class TransliterationModulesNew(Enum):
    """
    Enum Class

    

    See Also:
        `API TransliterationModulesNew <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TransliterationModulesNew'
    __ooo_type_name__: str = 'enum'

    CharToNumHangul_ko = 'CharToNumHangul_ko'
    """
    Transliterate a Korean Hangul number string to ASCII number string.
    """
    CharToNumLower_ko = 'CharToNumLower_ko'
    """
    Transliterate a Korean Hanja lower case number string to ASCII number string.
    """
    CharToNumLower_zh_CN = 'CharToNumLower_zh_CN'
    """
    Transliterate a Simplified Chinese lower case number string to ASCII number string.
    """
    CharToNumLower_zh_TW = 'CharToNumLower_zh_TW'
    """
    Transliterate a Traditional Chinese lower case number string to ASCII number string.
    """
    CharToNumUpper_ko = 'CharToNumUpper_ko'
    """
    Transliterate a Korean Hanja upper case number string to ASCII number string.
    """
    CharToNumUpper_zh_CN = 'CharToNumUpper_zh_CN'
    """
    Transliterate a Simplified Chinese upper case number string to ASCII number string.
    """
    CharToNumUpper_zh_TW = 'CharToNumUpper_zh_TW'
    """
    Transliterate a Traditional Chinese upper case number string to ASCII number string.
    """
    END_OF_MODULE = 'END_OF_MODULE'
    """
    """
    FULLWIDTH_HALFWIDTH = 'FULLWIDTH_HALFWIDTH'
    """
    Transliterate a string from full width character to half width character.
    """
    HALFWIDTH_FULLWIDTH = 'HALFWIDTH_FULLWIDTH'
    """
    Transliterate a string from half width character to full width character.
    """
    HIRAGANA_KATAKANA = 'HIRAGANA_KATAKANA'
    """
    Transliterate a Japanese string from Hiragana to Katakana.
    """
    IGNORE_CASE = 'IGNORE_CASE'
    """
    Ignore case when comparing strings by transliteration service.
    """
    IGNORE_KANA = 'IGNORE_KANA'
    """
    Ignore Hiragana and Katakana when comparing strings by transliteration service.
    """
    IGNORE_WIDTH = 'IGNORE_WIDTH'
    """
    Ignore full width and half width character when comparing strings by transliteration service.
    
    Ignore full width and half width characters when comparing strings by transliteration service.
    """
    IgnoreBaFa_ja_JP = 'IgnoreBaFa_ja_JP'
    """
    Ignore Katakana and Hiragana Ba/Gua and Ha/Fa in Japanese fuzzy search.
    """
    IgnoreHyuByu_ja_JP = 'IgnoreHyuByu_ja_JP'
    """
    Ignore Katakana and Hiragana Hyu/Fyu and Byu/Gyu in Japanese fuzzy search.
    """
    IgnoreIandEfollowedByYa_ja_JP = 'IgnoreIandEfollowedByYa_ja_JP'
    """
    Ignore Katakana YA/A which follows the character in either I or E row in Japanese fuzzy search.
    
    Ignore Katakana YA/A following the character in either I or E row in Japanese fuzzy search.
    """
    IgnoreIterationMark_ja_JP = 'IgnoreIterationMark_ja_JP'
    """
    Ignore Hiragana and Katakana iteration mark in Japanese fuzzy search.
    """
    IgnoreKiKuFollowedBySa_ja_JP = 'IgnoreKiKuFollowedBySa_ja_JP'
    """
    Ignore Katakana KI/KU which follows the character in SA column in Japanese fuzzy search.
    
    Ignore Katakana KI/KU following the character in SA column in Japanese fuzzy search.
    """
    IgnoreMiddleDot_ja_JP = 'IgnoreMiddleDot_ja_JP'
    """
    Ignore middle dot in Japanese fuzzy search.
    """
    IgnoreMinusSign_ja_JP = 'IgnoreMinusSign_ja_JP'
    """
    Ignore dash or minus sign in Japanese fuzzy search.
    """
    IgnoreProlongedSoundMark_ja_JP = 'IgnoreProlongedSoundMark_ja_JP'
    """
    Ignore Japanese prolonged sound mark in Japanese fuzzy search.
    """
    IgnoreSeZe_ja_JP = 'IgnoreSeZe_ja_JP'
    """
    Ignore Katakana and Hiragana Se/Sye and Ze/Je in Japanese fuzzy search.
    """
    IgnoreSeparator_ja_JP = 'IgnoreSeparator_ja_JP'
    """
    Ignore separator punctuations in Japanese fuzzy search.
    """
    IgnoreSize_ja_JP = 'IgnoreSize_ja_JP'
    """
    Ignore Japanese normal and small sized character in Japanese fuzzy search.
    """
    IgnoreSpace_ja_JP = 'IgnoreSpace_ja_JP'
    """
    Ignore white space characters, include space, TAB, return, etc. in Japanese fuzzy search.
    """
    IgnoreTiJi_ja_JP = 'IgnoreTiJi_ja_JP'
    """
    Ignore Katakana and Hiragana Tsui/Tea/Ti and Dyi/Ji in Japanese fuzzy search.
    """
    IgnoreTraditionalKana_ja_JP = 'IgnoreTraditionalKana_ja_JP'
    """
    Ignore Japanese traditional Katakana and Hiragana character in Japanese fuzzy search.
    
    Ignore Japanese traditional Katakana and Hiragana characters in Japanese fuzzy search.
    """
    IgnoreTraditionalKanji_ja_JP = 'IgnoreTraditionalKanji_ja_JP'
    """
    Ignore Japanese traditional Kanji character in Japanese fuzzy search.
    
    Ignore Japanese traditional Kanji characters in Japanese fuzzy search.
    """
    IgnoreZiZu_ja_JP = 'IgnoreZiZu_ja_JP'
    """
    Ignore Katakana and Hiragana Zi/Zi and Zu/Zu in Japanese fuzzy search.
    """
    KATAKANA_HIRAGANA = 'KATAKANA_HIRAGANA'
    """
    Transliterate a Japanese string from Katakana to Hiragana.
    """
    LOWERCASE_UPPERCASE = 'LOWERCASE_UPPERCASE'
    """
    Transliterate a string from lower case to upper case.
    """
    LargeToSmall_ja_JP = 'LargeToSmall_ja_JP'
    """
    transliterate Japanese normal sized character to small sized character
    """
    NumToCharFullwidth = 'NumToCharFullwidth'
    """
    Transliterate a half width number string to full width number string.
    """
    NumToCharHangul_ko = 'NumToCharHangul_ko'
    """
    Transliterate an ASCII number string to Korean Hangul number string.
    """
    NumToCharKanjiShort_ja_JP = 'NumToCharKanjiShort_ja_JP'
    """
    Transliterate an ASCII number string to Japanese Kanji number string.
    """
    NumToCharLower_ko = 'NumToCharLower_ko'
    """
    Transliterate an ASCII number string to Korean Hanja lower case number string.
    """
    NumToCharLower_zh_CN = 'NumToCharLower_zh_CN'
    """
    Transliterate an ASCII number string to Simplified Chinese lower case number string.
    """
    NumToCharLower_zh_TW = 'NumToCharLower_zh_TW'
    """
    Transliterate an ASCII number string to Traditional Chinese lower case number string.
    """
    NumToCharUpper_ko = 'NumToCharUpper_ko'
    """
    Transliterate an ASCII number string to Korean Hanja upper case number string.
    """
    NumToCharUpper_zh_CN = 'NumToCharUpper_zh_CN'
    """
    Transliterate an ASCII number string to Simplified Chinese upper case number string.
    """
    NumToCharUpper_zh_TW = 'NumToCharUpper_zh_TW'
    """
    Transliterate an ASCII number string to Traditional Chinese upper case number string.
    """
    NumToTextFormalHangul_ko = 'NumToTextFormalHangul_ko'
    """
    Transliterate an ASCII number string to formal Korean Hangul number string in spellout format.
    """
    NumToTextFormalLower_ko = 'NumToTextFormalLower_ko'
    """
    Transliterate an ASCII number string to formal Korean Hanja lower case number string in spellout format.
    """
    NumToTextFormalUpper_ko = 'NumToTextFormalUpper_ko'
    """
    Transliterate an ASCII number string to formal Korean Hanja upper case number string in spellout format.
    """
    NumToTextInformalHangul_ko = 'NumToTextInformalHangul_ko'
    """
    Transliterate an ASCII number string to informal Korean Hangul number string in spellout format.
    """
    NumToTextInformalLower_ko = 'NumToTextInformalLower_ko'
    """
    Transliterate an ASCII number string to informal Korean Hanja lower case number string in spellout format.
    """
    NumToTextInformalUpper_ko = 'NumToTextInformalUpper_ko'
    """
    Transliterate an ASCII number string to informal Korean Hanja upper case number string in spellout format.
    """
    NumToTextLower_zh_CN = 'NumToTextLower_zh_CN'
    """
    Transliterate an ASCII number string to Simplified Chinese lower case number string in spellout format.
    """
    NumToTextLower_zh_TW = 'NumToTextLower_zh_TW'
    """
    Transliterate an ASCII number string to Traditional Chinese lower case number string in spellout format.
    """
    NumToTextUpper_zh_CN = 'NumToTextUpper_zh_CN'
    """
    Transliterate an ASCII number string to Simplified Chinese upper case number string in spellout format.
    """
    NumToTextUpper_zh_TW = 'NumToTextUpper_zh_TW'
    """
    Transliterate an ASCII number string to Traditional Chinese upper case number string in spellout format.
    """
    SmallToLarge_ja_JP = 'SmallToLarge_ja_JP'
    """
    transliterate Japanese small sized character to normal sized character
    """
    TextToNumFormalHangul_ko = 'TextToNumFormalHangul_ko'
    """
    Transliterate a Korean formal Hangul number string (spellout) to ASCII number string.
    """
    TextToNumFormalLower_ko = 'TextToNumFormalLower_ko'
    """
    Transliterate a Korean formal Hanja lower case number string (spellout) to ASCII number string.
    """
    TextToNumFormalUpper_ko = 'TextToNumFormalUpper_ko'
    """
    Transliterate a Korean formal Hanja upper case number string (spellout) to ASCII number string.
    """
    TextToNumInformalHangul_ko = 'TextToNumInformalHangul_ko'
    """
    Transliterate a Korean informal Hangul number string (spellout) to ASCII number string.
    """
    TextToNumInformalLower_ko = 'TextToNumInformalLower_ko'
    """
    Transliterate a Korean informal Hanja lower case number string (spellout) to ASCII number string.
    """
    TextToNumInformalUpper_ko = 'TextToNumInformalUpper_ko'
    """
    Transliterate a Korean informal Hanja upper case number string (spellout) to ASCII number string.
    """
    TextToNumLower_zh_CN = 'TextToNumLower_zh_CN'
    """
    Transliterate a Simplified Chinese lower case number string (spellout) to ASCII number string.
    """
    TextToNumLower_zh_TW = 'TextToNumLower_zh_TW'
    """
    Transliterate a Traditional Chinese lower case number string (spellout) to ASCII number string.
    """
    TextToNumUpper_zh_CN = 'TextToNumUpper_zh_CN'
    """
    Transliterate a Simplified Chinese upper case number string (spellout) to ASCII number string.
    """
    TextToNumUpper_zh_TW = 'TextToNumUpper_zh_TW'
    """
    Transliterate a Traditional Chinese upper case number string (spellout) to ASCII number string.
    """
    UPPERCASE_LOWERCASE = 'UPPERCASE_LOWERCASE'
    """
    Transliterate a string from upper case to lower case.
    """

__all__ = ['TransliterationModulesNew']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n


class NumberFormatIndex(object):
    """
    Const Class

    Do NOT insert any new values! Locale data number format creation must match these values! Number formatter internals must match these values!
    
    Number format indices to be passed as the index argument to XNumberFormatCode.getFormatCode() or com.sun.star.util.XNumberFormatTypes.getFormatIndex().
    
    Each locale can support up to about 5000 arbitrary format codes. But for backward compatibility reasons, each locale MUST support some predefined format codes. These predefined format codes are accessed through indices as the following, and the locale data format code definitions in i18npool/source/localedata/data/*.xml MUST have matching entries in the form
    
    <FormatElement formatindex=\"0\">
    
    (see also FormatElement.formatIndex()).
    
    The index values are also used to define the enum NfIndexTableOffset in file svtools/inc/zforlist.hxx
    
    Note: This index has nothing to do with the index key used internally by the number formatter.
    
    Date formats may have a comment of DIN/EN/ISO, meaning
    
    Some names of date format constants indicate a special behavior of those formats in StarOffice 5.2 or older. Those are:

    See Also:
        `API NumberFormatIndex <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1NumberFormatIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.NumberFormatIndex'
    __ooo_type_name__: str = 'const'

    NUMBER_START = 0
    """
    Start of simple numerical formats (first format)
    """
    NUMBER_STANDARD = NUMBER_START
    """
    The \"General\" standard format
    formatindex=\"0\".
    """
    NUMBER_INT = NUMBER_START + 1
    """
    0
    Integer number
    formatindex=\"1\"
    """
    NUMBER_DEC2 = NUMBER_START + 2
    """
    0.00
    Decimal number with 2 decimals
    formatindex=\"2\"
    """
    NUMBER_1000INT = NUMBER_START + 3
    """
    #,##0
    Integer number with group separator
    formatindex=\"3\"
    """
    NUMBER_1000DEC2 = NUMBER_START + 4
    """
    #,##0.00
    Decimal number with group separator
    formatindex=\"4\"
    """
    NUMBER_SYSTEM = NUMBER_START + 5
    """
    #,##0.00
    In SO5/Win this format was retrieved from the Regional Settings
    formatindex=\"5\"
    """
    NUMBER_END = NUMBER_SYSTEM
    """
    End of simple numerical formats (last format)
    """
    SCIENTIFIC_START = NUMBER_END + 1
    """
    Start of Scientific formats (first format)
    """
    SCIENTIFIC_000E000 = SCIENTIFIC_START
    """
    0.00E+000
    Number in scientific notation with exponent in 3 digit placeholders
    formatindex=\"6\"
    """
    SCIENTIFIC_000E00 = SCIENTIFIC_START + 1
    """
    0.00E+00
    Number in scientific notation with exponent in 2 digit placeholders
    formatindex=\"7\"
    """
    SCIENTIFIC_END = SCIENTIFIC_000E00
    """
    End of Scientific formats (last format)
    """
    PERCENT_START = SCIENTIFIC_END + 1
    """
    Start of Percent formats (first format)
    """
    PERCENT_INT = PERCENT_START
    """
    0%
    Percentage format, rounded to integer
    formatindex=\"8\"
    """
    PERCENT_DEC2 = PERCENT_START + 1
    """
    0.00%
    Percentage format, rounded to 2 decimals
    formatindex=\"9\"
    """
    PERCENT_END = PERCENT_DEC2
    """
    End of Percent formats (last format)
    """
    FRACTION_START = PERCENT_END + 1
    """
    Start of Fraction formats (first format)
    """
    FRACTION_1 = FRACTION_START
    FRACTION_2 = FRACTION_START + 1
    FRACTION_END = FRACTION_2
    """
    End of Fraction formats (last format)
    """
    CURRENCY_START = FRACTION_END + 1
    """
    Start of Currency formats (first format)
    """
    CURRENCY_1000INT = CURRENCY_START
    """
    #,##0 DM
    Integer currency format with group separator
    formatindex=\"12\"
    """
    CURRENCY_1000DEC2 = CURRENCY_START + 1
    """
    #,##0.00 DM
    Decimal currency format with group separator
    formatindex=\"13\"
    """
    CURRENCY_1000INT_RED = CURRENCY_START + 2
    """
    #,##0 DM
    Integer currency format with negative in red
    formatindex=\"14\"
    """
    CURRENCY_1000DEC2_RED = CURRENCY_START + 3
    """
    #,##0.00 DM
    Decimal currency format with negative in red
    formatindex=\"15\"
    """
    CURRENCY_1000DEC2_CCC = CURRENCY_START + 4
    """
    #,##0.00 DEM
    Currency in ISO-4217 abbreviation format
    formatindex=\"16\"
    """
    CURRENCY_1000DEC2_DASHED = CURRENCY_START + 5
    """
    #,##0.– DM
    Currency format with dash representing 0 in decimals
    formatindex=\"17\"
    """
    CURRENCY_END = CURRENCY_1000DEC2_DASHED
    """
    End of Currency formats (last format)
    """
    DATE_START = CURRENCY_END + 1
    """
    Start of Date formats (first format)
    """
    DATE_SYSTEM_SHORT = DATE_START
    """
    08.10.97
    see also DATE_SYSTEM_... explanation
    formatindex=\"18\"
    """
    DATE_SYSTEM_LONG = DATE_START + 1
    """
    Wednesday, 8.
    
    October 1997
    see also DATE_SYSTEM_... explanation
    formatindex=\"19\"
    """
    DATE_SYS_DDMMYY = DATE_START + 2
    """
    08.10.97
    see also DATE_SYS_... explanation
    formatindex=\"20\"
    """
    DATE_SYS_DDMMYYYY = DATE_START + 3
    """
    08.10.1997
    see also DATE_SYS_...
    
    explanation
    Note: When editing already existing date data this format is forced in order to always edit the full century.
    formatindex=\"21\"
    """
    DATE_SYS_DMMMYY = DATE_START + 4
    DATE_SYS_DMMMYYYY = DATE_START + 5
    DATE_DIN_DMMMYYYY = DATE_START + 6
    DATE_SYS_DMMMMYYYY = DATE_START + 7
    DATE_DIN_DMMMMYYYY = DATE_START + 8
    DATE_SYS_NNDMMMYY = DATE_START + 9
    """
    Wed, 8. Oct 97
    see also DATE_SYS_... explanation
    formatindex=\"27\".
    """
    DATE_DEF_NNDDMMMYY = DATE_START + 10
    """
    Wed 08.Oct 97
    see also DATE_DEF_... explanation
    formatindex=\"28\".
    """
    DATE_SYS_NNDMMMMYYYY = DATE_START + 11
    """
    Wed, 8. October 1997
    see also DATE_SYS_... explanation
    formatindex=\"29\".
    """
    DATE_SYS_NNNNDMMMMYYYY = DATE_START + 12
    """
    Wednesday, 8. October 1997
    formatindex=\"30\".
    """
    DATE_DIN_MMDD = DATE_START + 13
    """
    10-08
    DIN/EN
    formatindex=\"31\"
    """
    DATE_DIN_YYMMDD = DATE_START + 14
    """
    97-10-08
    DIN/EN
    formatindex=\"32\"
    """
    DATE_DIN_YYYYMMDD = DATE_START + 15
    """
    1997-10-08
    DIN/EN/ISO
    formatindex=\"33\"
    """
    DATE_SYS_MMYY = DATE_START + 16
    """
    10.97
    see also DATE_SYS_... explanation
    formatindex=\"34\"
    """
    DATE_SYS_DDMMM = DATE_START + 17
    """
    08.Oct
    see also DATE_SYS_... explanation
    formatindex=\"35\"
    """
    DATE_MMMM = DATE_START + 18
    """
    October
    formatindex=\"36\".
    """
    DATE_QQJJ = DATE_START + 19
    """
    4th quarter 97
    formatindex=\"37\"
    """
    DATE_WW = DATE_START + 20
    """
    week of year
    formatindex=\"38\"
    """
    DATE_END = DATE_WW
    """
    End of Date formats (last format)
    """
    TIME_START = DATE_END + 1
    """
    Start of Time formats (first format)
    """
    TIME_HHMM = TIME_START
    """
    HH:MM
    Time format with hour and minute
    formatindex=\"39\".
    """
    TIME_HHMMSS = TIME_START + 1
    """
    HH:MM:SS
    Time format with hour, minute and second
    formatindex=\"40\".
    """
    TIME_HHMMAMPM = TIME_START + 2
    """
    HH:MM AM/PM
    Time format with hour, minute and morning/afternoon notation
    formatindex=\"41\".
    """
    TIME_HHMMSSAMPM = TIME_START + 3
    """
    HH:MM:SS AM/PM
    Time format with hour, minute, second and morning/afternoon notation
    formatindex=\"42\".
    """
    TIME_HH_MMSS = TIME_START + 4
    """
    [HH]:MM:SS
    Time format with amount of hours
    formatindex=\"43\"
    """
    TIME_MMSS00 = TIME_START + 5
    """
    MM:SS,00
    Time format with second in fraction
    formatindex=\"44\".
    """
    TIME_HH_MMSS00 = TIME_START + 6
    """
    [HH]:MM:SS,00
    Time format with amount of hours and seconds with fraction
    formatindex=\"45\"
    """
    TIME_END = TIME_HH_MMSS00
    """
    End of Time formats (last format)
    """
    DATETIME_START = TIME_END + 1
    """
    Start of DateTime formats (first format)
    """
    DATETIME_SYSTEM_SHORT_HHMM = DATETIME_START
    """
    08.10.97 01:23 Date/time format
    formatindex=\"46\"
    """
    DATETIME_SYS_DDMMYYYY_HHMMSS = DATETIME_START + 1
    """
    08.10.1997 01:23:45 Date/time format with second
    Note: When editing already existing date/time data this format is forced in order to always edit the full century.
    
    formatindex=\"47\"
    """
    DATETIME_END = DATETIME_SYS_DDMMYYYY_HHMMSS
    """
    End of DateTime formats (last format)
    """
    BOOLEAN = DATETIME_END + 1
    """
    BOOLEAN format.
    """
    TEXT = BOOLEAN + 1
    """
    Text format.
    """
    INDEX_TABLE_ENTRIES = TEXT + 1
    """
    count of built-in format codes.
    """

__all__ = ['NumberFormatIndex']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form
import typing
from abc import abstractmethod
from ..ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ..awt.x_control_container import XControlContainer as XControlContainer_e22d0d30
    from ..awt.x_tab_controller_model import XTabControllerModel as XTabControllerModel_fbef0dd8
    from ..awt.x_window import XWindow as XWindow_713b0924

class TabOrderDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API TabOrderDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1TabOrderDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.TabOrderDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createWithModel(self, TabbingModel: 'XTabControllerModel_fbef0dd8', ControlContext: 'XControlContainer_e22d0d30', ParentWindow: 'XWindow_713b0924') -> None:
        """
        """


__all__ = ['TabOrderDialog']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from abc import abstractproperty
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from ..document.x_action_lockable import XActionLockable as XActionLockable_cb30e3a
from .sheet_ranges_query import SheetRangesQuery as SheetRangesQuery_efbe0d90
from .x_cell_addressable import XCellAddressable as XCellAddressable_ed700d53
from .x_sheet_annotation_anchor import XSheetAnnotationAnchor as XSheetAnnotationAnchor_48670fe8
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
from ..table.cell import Cell as Cell_680c0890
from ..table.x_column_row_range import XColumnRowRange as XColumnRowRange_e0e70cfb
from ..text.text import Text as Text_607f0872
from ..text.x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier_d5d0e75
from ..util.x_indent import XIndent as XIndent_7b290980
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.size import Size as Size_576707ef
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries_694810c0
    from ..table.cell_content_type import CellContentType as CellContentType_e08c0d0d

class SheetCell(SheetRangesQuery_efbe0d90, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4, Cell_680c0890, Text_607f0872, XTolerantMultiPropertySet_7bd4114e, XActionLockable_cb30e3a, XCellAddressable_ed700d53, XSheetAnnotationAnchor_48670fe8, XColumnRowRange_e0e70cfb, XTextFieldsSupplier_d5d0e75, XIndent_7b290980, XModifyBroadcaster_fd990df0, XReplaceable_b0750b6e):
    """
    Service Class

    represents a single addressable cell in a spreadsheet document.
    
    **since**
    
        OOo 2.0

    See Also:
        `API SheetCell <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCell.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetCell'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AbsoluteName(self) -> str:
        """
        Returns the absolute address of the range as string, e.g.
        
        \"$Sheet1.$B$2\".
        """

    @abstractproperty
    def CellContentType(self) -> 'CellContentType_e08c0d0d':
        """
        contains the content type of the cell.
        
        **since**
        
            LibreOffice 6.1
        """

    @abstractproperty
    def ConditionalFormat(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """

    @abstractproperty
    def ConditionalFormatLocal(self) -> 'XSheetConditionalEntries_694810c0':
        """
        contains the conditional formatting settings for this cell, using localized formulas.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """

    @abstractproperty
    def FormulaLocal(self) -> str:
        """
        contains the formula string with localized function names.
        
        This property can also be used to set a new localized formula.
        """

    @abstractproperty
    def FormulaResultType(self) -> int:
        """
        contains the content type of the cell.
        
        This property returns not com.sun.star.sheet.FormulaResult but instead com.sun.star.table.CellContentType. Use FormulaResult2 if the correct property is needed.
        """

    @abstractproperty
    def FormulaResultType2(self) -> int:
        """
        contains the result type of a formula.
        
        **since**
        
            LibreOffice 6.1
        """

    @abstractproperty
    def Position(self) -> 'Point_5fb2085e':
        """
        contains the position of this cell in the sheet (in 1/100 mm).
        
        This property contains the absolute position in the whole sheet, not the position in the visible area.
        """

    @abstractproperty
    def Size(self) -> 'Size_576707ef':
        """
        contains the size of this cell (in 1/100 mm).
        """

    @abstractproperty
    def Validation(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """

    @abstractproperty
    def ValidationLocal(self) -> 'XPropertySet_bc180bfa':
        """
        contains the data validation settings for this cell, using localized formulas.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """



__all__ = ['SheetCell']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
import typing
from abc import abstractmethod
from .x_shape import XShape as XShape_8fd00a3d
if typing.TYPE_CHECKING:
    from .connection_type import ConnectionType as ConnectionType_f1940da6
    from .x_connectable_shape import XConnectableShape as XConnectableShape_1abe0e9b

class XConnectorShape(XShape_8fd00a3d):
    """
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XConnectorShape <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XConnectorShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XConnectorShape'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XConnectorShape'

    @abstractmethod
    def connectEnd(self, xShape: 'XConnectableShape_1abe0e9b', nPos: 'ConnectionType_f1940da6') -> None:
        """
        connects the end of this instance.
        """
    @abstractmethod
    def connectStart(self, xShape: 'XConnectableShape_1abe0e9b', nPos: 'ConnectionType_f1940da6') -> None:
        """
        connects the start of this instance
        """
    @abstractmethod
    def disconnectBegin(self, xShape: 'XConnectableShape_1abe0e9b') -> None:
        """
        disconnects the given Shape from the start of this instance.
        """
    @abstractmethod
    def disconnectEnd(self, xShape: 'XConnectableShape_1abe0e9b') -> None:
        """
        disconnects the given Shape from the end of this instance.
        """

__all__ = ['XConnectorShape']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing.framework
# Libre Office Version: 7.3
from enum import Enum


class ResourceActivationMode(Enum):
    """
    Enum Class

    

    See Also:
        `API ResourceActivationMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1framework.html#a9b6ee17a97f260847a6fa2df1be8f104>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.ResourceActivationMode'
    __ooo_type_name__: str = 'enum'

    ADD = 'ADD'
    """
    A resource is requested in addition to already existing ones.
    
    This is used for example for panes.
    """
    REPLACE = 'REPLACE'
    """
    A resource is requested to replace an already existing one of the same class.
    
    This is used for example for views.
    """

__all__ = ['ResourceActivationMode']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.embed import Aspects as Aspects
    if hasattr(Aspects, '_constants') and isinstance(Aspects._constants, dict):
        Aspects._constants['__ooo_ns__'] = 'com.sun.star.embed'
        Aspects._constants['__ooo_full_ns__'] = 'com.sun.star.embed.Aspects'
        Aspects._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global AspectsEnum
        ls = [f for f in dir(Aspects) if not callable(getattr(Aspects, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(Aspects, name)
        AspectsEnum = IntFlag('AspectsEnum', _dict)
    build_enum()
else:
    from ...lo.embed.aspects import Aspects as Aspects

    class AspectsEnum(IntFlag):
        """
        Enum of Const Class Aspects

        The constant set contains possible aspects for an embedded object.
        
        This constant set provides a set of values that can be used to specify the kind of object view. It can be used for example by container to request view representation of a certain kind from XEmbeddedObject.
        
        The first 32 bits are reserved for MS OLE aspects.
        """
        MSOLE_CONTENT = Aspects.MSOLE_CONTENT
        """
        specifies view of the object to be displayed as an embedded object inside a container.
        """
        MSOLE_THUMBNAIL = Aspects.MSOLE_THUMBNAIL
        """
        specifies view of the object to be displayed in a browsing tool.
        """
        MSOLE_ICON = Aspects.MSOLE_ICON
        """
        specifies view of the object when object is represented by Icon.
        """
        MSOLE_DOCPRINT = Aspects.MSOLE_DOCPRINT
        """
        specifies view of the object for print preview.
        """

__all__ = ['Aspects', 'AspectsEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import FocusChangeReason as FocusChangeReason
    if hasattr(FocusChangeReason, '_constants') and isinstance(FocusChangeReason._constants, dict):
        FocusChangeReason._constants['__ooo_ns__'] = 'com.sun.star.awt'
        FocusChangeReason._constants['__ooo_full_ns__'] = 'com.sun.star.awt.FocusChangeReason'
        FocusChangeReason._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FocusChangeReasonEnum
        ls = [f for f in dir(FocusChangeReason) if not callable(getattr(FocusChangeReason, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FocusChangeReason, name)
        FocusChangeReasonEnum = IntFlag('FocusChangeReasonEnum', _dict)
    build_enum()
else:
    from ...lo.awt.focus_change_reason import FocusChangeReason as FocusChangeReason

    class FocusChangeReasonEnum(IntFlag):
        """
        Enum of Const Class FocusChangeReason

        A combination of these values can be used to specify the reason for a focus change.
        """
        TAB = FocusChangeReason.TAB
        """
        Focus changed because TAB was pressed.
        """
        CURSOR = FocusChangeReason.CURSOR
        """
        Focus changed because Key Left/Right/Up/Down was pressed.
        """
        MNEMONIC = FocusChangeReason.MNEMONIC
        """
        Focus changed because mnemonic key was pressed.
        """
        FORWARD = FocusChangeReason.FORWARD
        """
        Changed Focus to the next control.
        """
        BACKWARD = FocusChangeReason.BACKWARD
        """
        Changed Focus to the previous control.
        """
        AROUND = FocusChangeReason.AROUND
        """
        Changed Focus forward from last to first or backward from first to last.
        """
        UNIQUEMNEMONIC = FocusChangeReason.UNIQUEMNEMONIC
        """
        Focus changed because mnemonic key was pressed and this mnemonic is unique.
        """

__all__ = ['FocusChangeReason', 'FocusChangeReasonEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...dyn.script.all_event_object import AllEventObject as AllEventObject
from ...dyn.script.all_listener_adapter import AllListenerAdapter as AllListenerAdapter
from ...dyn.script.array_wrapper import ArrayWrapper as ArrayWrapper
from ...dyn.script.basic_error_exception import BasicErrorException as BasicErrorException
from ...dyn.script.cannot_convert_exception import CannotConvertException as CannotConvertException
from ...dyn.script.cannot_create_adapter_exception import CannotCreateAdapterException as CannotCreateAdapterException
from ...dyn.script.context_information import ContextInformation as ContextInformation
from ...dyn.script.converter import Converter as Converter
from ...dyn.script.document_dialog_library_container import DocumentDialogLibraryContainer as DocumentDialogLibraryContainer
from ...dyn.script.document_script_library_container import DocumentScriptLibraryContainer as DocumentScriptLibraryContainer
from ...dyn.script.engine import Engine as Engine
from ...dyn.script.event_listener import EventListener as EventListener
from ...dyn.script.fail_reason import FailReason as FailReason
from ...dyn.script.fail_reason import FailReasonEnum as FailReasonEnum
from ...dyn.script.finish_engine_event import FinishEngineEvent as FinishEngineEvent
from ...dyn.script.finish_reason import FinishReason as FinishReason
from ...dyn.script.interrupt_engine_event import InterruptEngineEvent as InterruptEngineEvent
from ...dyn.script.interrupt_reason import InterruptReason as InterruptReason
from ...dyn.script.invocation import Invocation as Invocation
from ...dyn.script.invocation_adapter_factory import InvocationAdapterFactory as InvocationAdapterFactory
from ...dyn.script.invocation_info import InvocationInfo as InvocationInfo
from ...dyn.script.java_script import JavaScript as JavaScript
from ...dyn.script.library_not_loaded_exception import LibraryNotLoadedException as LibraryNotLoadedException
from ...dyn.script.member_type import MemberType as MemberType
from ...dyn.script.module_info import ModuleInfo as ModuleInfo
from ...dyn.script.module_size_exceeded_request import ModuleSizeExceededRequest as ModuleSizeExceededRequest
from ...dyn.script.module_type import ModuleType as ModuleType
from ...dyn.script.module_type import ModuleTypeEnum as ModuleTypeEnum
from ...dyn.script.native_object_wrapper import NativeObjectWrapper as NativeObjectWrapper
from ...dyn.script.script_event import ScriptEvent as ScriptEvent
from ...dyn.script.script_event_descriptor import ScriptEventDescriptor as ScriptEventDescriptor
from ...dyn.script.x_all_listener import XAllListener as XAllListener
from ...dyn.script.x_all_listener_adapter_service import XAllListenerAdapterService as XAllListenerAdapterService
from ...dyn.script.x_automation_invocation import XAutomationInvocation as XAutomationInvocation
from ...dyn.script.x_debugging import XDebugging as XDebugging
from ...dyn.script.x_default_method import XDefaultMethod as XDefaultMethod
from ...dyn.script.x_default_property import XDefaultProperty as XDefaultProperty
from ...dyn.script.x_direct_invocation import XDirectInvocation as XDirectInvocation
from ...dyn.script.x_engine import XEngine as XEngine
from ...dyn.script.x_engine_listener import XEngineListener as XEngineListener
from ...dyn.script.x_error_query import XErrorQuery as XErrorQuery
from ...dyn.script.x_event_attacher import XEventAttacher as XEventAttacher
from ...dyn.script.x_event_attacher2 import XEventAttacher2 as XEventAttacher2
from ...dyn.script.x_event_attacher_manager import XEventAttacherManager as XEventAttacherManager
from ...dyn.script.x_invocation import XInvocation as XInvocation
from ...dyn.script.x_invocation2 import XInvocation2 as XInvocation2
from ...dyn.script.x_invocation_adapter_factory import XInvocationAdapterFactory as XInvocationAdapterFactory
from ...dyn.script.x_invocation_adapter_factory2 import XInvocationAdapterFactory2 as XInvocationAdapterFactory2
from ...dyn.script.x_library_access import XLibraryAccess as XLibraryAccess
from ...dyn.script.x_library_container import XLibraryContainer as XLibraryContainer
from ...dyn.script.x_library_container2 import XLibraryContainer2 as XLibraryContainer2
from ...dyn.script.x_library_container3 import XLibraryContainer3 as XLibraryContainer3
from ...dyn.script.x_library_container_export import XLibraryContainerExport as XLibraryContainerExport
from ...dyn.script.x_library_container_password import XLibraryContainerPassword as XLibraryContainerPassword
from ...dyn.script.x_library_query_executable import XLibraryQueryExecutable as XLibraryQueryExecutable
from ...dyn.script.x_persistent_library_container import XPersistentLibraryContainer as XPersistentLibraryContainer
from ...dyn.script.x_script_events_attacher import XScriptEventsAttacher as XScriptEventsAttacher
from ...dyn.script.x_script_events_supplier import XScriptEventsSupplier as XScriptEventsSupplier
from ...dyn.script.x_script_listener import XScriptListener as XScriptListener
from ...dyn.script.x_service_documenter import XServiceDocumenter as XServiceDocumenter
from ...dyn.script.x_star_basic_access import XStarBasicAccess as XStarBasicAccess
from ...dyn.script.x_star_basic_dialog_info import XStarBasicDialogInfo as XStarBasicDialogInfo
from ...dyn.script.x_star_basic_library_info import XStarBasicLibraryInfo as XStarBasicLibraryInfo
from ...dyn.script.x_star_basic_module_info import XStarBasicModuleInfo as XStarBasicModuleInfo
from ...dyn.script.x_storage_based_library_container import XStorageBasedLibraryContainer as XStorageBasedLibraryContainer
from ...dyn.script.x_type_converter import XTypeConverter as XTypeConverter
from ...dyn.script.the_service_documenter import theServiceDocumenter as theServiceDocumenter



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_coordinate_system import XCoordinateSystem as XCoordinateSystem_7ff0e31

class XCoordinateSystemContainer(XInterface_8f010a43):
    """

    See Also:
        `API XCoordinateSystemContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XCoordinateSystemContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XCoordinateSystemContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XCoordinateSystemContainer'

    @abstractmethod
    def addCoordinateSystem(self, aCoordSys: 'XCoordinateSystem_7ff0e31') -> None:
        """
        add a coordinate system to the coordinate system container

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    @abstractmethod
    def getCoordinateSystems(self) -> 'typing.Tuple[XCoordinateSystem_7ff0e31, ...]':
        """
        retrieve all coordinate systems
        """
    @abstractmethod
    def removeCoordinateSystem(self, aCoordSys: 'XCoordinateSystem_7ff0e31') -> None:
        """
        removes one coordinate system from the coordinate system container.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    @abstractmethod
    def setCoordinateSystems(self, aCoordinateSystems: 'typing.Tuple[XCoordinateSystem_7ff0e31, ...]') -> None:
        """
        set all coordinate systems

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """

__all__ = ['XCoordinateSystemContainer']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....dyn.xml.xpath.libxml2_extension_handle import Libxml2ExtensionHandle as Libxml2ExtensionHandle
from ....dyn.xml.xpath.x_path_api import XPathAPI as XPathAPI
from ....dyn.xml.xpath.x_path_exception import XPathException as XPathException
from ....dyn.xml.xpath.x_path_extension import XPathExtension as XPathExtension
from ....dyn.xml.xpath.x_path_object_type import XPathObjectType as XPathObjectType
from ....dyn.xml.xpath.xx_path_api import XXPathAPI as XXPathAPI
from ....dyn.xml.xpath.xx_path_extension import XXPathExtension as XXPathExtension
from ....dyn.xml.xpath.xx_path_object import XXPathObject as XXPathObject



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.datatransfer
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XMimeContentType(XInterface_8f010a43):
    """
    An implementation of this interface represents a MIME content-type that conforms to Rfc2045 and Rfc2046.
    
    Instances that implement this interface could be created using the interface XMimeContentTypeFactory.

    See Also:
        `API XMimeContentType <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1XMimeContentType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.XMimeContentType'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.XMimeContentType'

    @abstractmethod
    def getFullMediaType(self) -> str:
        """
        To get the full media/submedia type of the MIME content-type.
        """
    @abstractmethod
    def getMediaSubtype(self) -> str:
        """
        To get the media subtype of the MIME content-type.
        """
    @abstractmethod
    def getMediaType(self) -> str:
        """
        To get the media type of the MIME content-type.
        """
    @abstractmethod
    def getParameterValue(self, aName: str) -> str:
        """
        To get the value of a specified parameter.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    @abstractmethod
    def getParameters(self) -> 'typing.Tuple[str, ...]':
        """
        To get a list of parameters that the MIME content-type contains.
        """
    @abstractmethod
    def hasParameter(self, aName: str) -> bool:
        """
        To query if a specific parameter is supported.
        
        A value of FALSE if the MIME content-type has not the specified parameter.
        """

__all__ = ['XMimeContentType']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.3
from enum import Enum


class CellVertJustify(Enum):
    """
    Enum Class

    

    See Also:
        `API CellVertJustify <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1table.html#a17834bec5bf9ac4432141dee1c03b50b>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellVertJustify'
    __ooo_type_name__: str = 'enum'

    BOTTOM = 'BOTTOM'
    """
    contents are aligned to the lower edge of the cell.
    """
    CENTER = 'CENTER'
    """
    contents are horizontally centered.
    
    contents are aligned to the vertical middle of the cell.
    """
    STANDARD = 'STANDARD'
    """
    default alignment is used (left for numbers, right for text).
    
    default alignment is used.
    
    contents are printed from left to right.
    """
    TOP = 'TOP'
    """
    contents are aligned with the upper edge of the cell.
    """

__all__ = ['CellVertJustify']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing.framework
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_configuration_controller import XConfigurationController as XConfigurationController_557c15c4
    from .x_module_controller import XModuleController as XModuleController_c5d112d2

class XControllerManager(ABC):
    """
    The XControllerManager gives access to the controllers of the drawing framework.
    
    The XControllerManager interface is typically implemented by the same object that implements com.sun.star.frame.XController.

    See Also:
        `API XControllerManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XControllerManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XControllerManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XControllerManager'

    @abstractmethod
    def getConfigurationController(self) -> 'XConfigurationController_557c15c4':
        """
        Return the XConfigurationController object.
        """
    @abstractmethod
    def getModuleController(self) -> 'XModuleController_c5d112d2':
        """
        Return the XModuleController object.
        """

__all__ = ['XControllerManager']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.xml
# Libre Office Version: 7.3
from ooo.oenv.env_const import UNO_NONE
import typing


class Attribute(object):
    """
    Struct Class

    A struct to keep information of an element's attribute.

    See Also:
        `API Attribute <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1xml_1_1Attribute.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.Attribute'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.xml.Attribute'
    """Literal Constant ``com.sun.star.xml.Attribute``"""

    def __init__(self, Name: typing.Optional[str] = '', NamespaceURL: typing.Optional[str] = '', Value: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            NamespaceURL (str, optional): NamespaceURL value.
            Value (str, optional): Value value.
        """
        super().__init__()

        if isinstance(Name, Attribute):
            oth: Attribute = Name
            self.Name = oth.Name
            self.NamespaceURL = oth.NamespaceURL
            self.Value = oth.Value
            return

        kargs = {
            "Name": Name,
            "NamespaceURL": NamespaceURL,
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._name = kwargs["Name"]
        self._namespace_url = kwargs["NamespaceURL"]
        self._value = kwargs["Value"]


    @property
    def Name(self) -> str:
        """
        the attribute name
        """
        return self._name
    
    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value

    @property
    def NamespaceURL(self) -> str:
        """
        the attribute namespace URL
        """
        return self._namespace_url
    
    @NamespaceURL.setter
    def NamespaceURL(self, value: str) -> None:
        self._namespace_url = value

    @property
    def Value(self) -> str:
        """
        the attribute value
        """
        return self._value
    
    @Value.setter
    def Value(self, value: str) -> None:
        self._value = value


__all__ = ['Attribute']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.script.provider
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.script.provider import ScriptFrameworkErrorType as ScriptFrameworkErrorType
    if hasattr(ScriptFrameworkErrorType, '_constants') and isinstance(ScriptFrameworkErrorType._constants, dict):
        ScriptFrameworkErrorType._constants['__ooo_ns__'] = 'com.sun.star.script.provider'
        ScriptFrameworkErrorType._constants['__ooo_full_ns__'] = 'com.sun.star.script.provider.ScriptFrameworkErrorType'
        ScriptFrameworkErrorType._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ScriptFrameworkErrorTypeEnum
        ls = [f for f in dir(ScriptFrameworkErrorType) if not callable(getattr(ScriptFrameworkErrorType, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ScriptFrameworkErrorType, name)
        ScriptFrameworkErrorTypeEnum = IntEnum('ScriptFrameworkErrorTypeEnum', _dict)
    build_enum()
else:
    from ....lo.script.provider.script_framework_error_type import ScriptFrameworkErrorType as ScriptFrameworkErrorType

    class ScriptFrameworkErrorTypeEnum(IntEnum):
        """
        Enum of Const Class ScriptFrameworkErrorType

        is a checked exception that represents an error encountered by the Scripting Framework whilst executing a script
        """
        UNKNOWN = ScriptFrameworkErrorType.UNKNOWN
        """
        Unknown.
        """
        NOTSUPPORTED = ScriptFrameworkErrorType.NOTSUPPORTED
        """
        ProviderNotSupported.
        """
        NO_SUCH_SCRIPT = ScriptFrameworkErrorType.NO_SUCH_SCRIPT
        """
        the requested method, and/or with the requested signature, does not exist
        """
        MALFORMED_URL = ScriptFrameworkErrorType.MALFORMED_URL
        """
        the requested method, with the requested signature, does not exist
        """

__all__ = ['ScriptFrameworkErrorType', 'ScriptFrameworkErrorTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from .x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch_bc10e52

class ContentHandler(XNotifyingDispatch_bc10e52):
    """
    Service Class

    special dispatcher for non visible contents, e.g.
    
    sounds
    
    This handler doesn't need any frame as target for loading components. Content handler are registered for content types. (See type/filter configuration of com.sun.star.document.TypeDetection for further information) If generic load mechanism found such documents which can be handled by a ContentHandler it will create and use it.

    See Also:
        `API ContentHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1ContentHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.ContentHandler'
    __ooo_type_name__: str = 'service'



__all__ = ['ContentHandler']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_data_pilot_results import XDataPilotResults as XDataPilotResults_fc0c0ded
from .x_dimensions_supplier import XDimensionsSupplier as XDimensionsSupplier_1baa0ee6
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class DataPilotSource(XPropertySet_bc180bfa, XDataPilotResults_fc0c0ded, XDimensionsSupplier_1baa0ee6, XRefreshable_b0d60b81):
    """
    Service Class

    represents a data pilot source.
    
    A component that implements this service can be used as data source for a data pilot table in a spreadsheet document.
    
    **since**
    
        OOo 3.0

    See Also:
        `API DataPilotSource <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSource.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotSource'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ColumnFieldCount(self) -> int:
        """
        specifies the number of column fields.
        
        **since**
        
            OOo 3.0
        """

    @abstractproperty
    def ColumnGrand(self) -> bool:
        """
        specifies if grand totals for the columns are inserted.
        """

    @abstractproperty
    def DataFieldCount(self) -> int:
        """
        specifies the number of data fields.
        
        **since**
        
            OOo 3.0
        """

    @abstractproperty
    def RowFieldCount(self) -> int:
        """
        specifies the number of row fields.
        
        **since**
        
            OOo 3.0
        """

    @abstractproperty
    def RowGrand(self) -> bool:
        """
        specifies if grand totals for the rows are inserted.
        """



__all__ = ['DataPilotSource']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt


class FocusChangeReason(object):
    """
    Const Class

    A combination of these values can be used to specify the reason for a focus change.

    See Also:
        `API FocusChangeReason <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FocusChangeReason.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FocusChangeReason'
    __ooo_type_name__: str = 'const'

    TAB = 1
    """
    Focus changed because TAB was pressed.
    """
    CURSOR = 2
    """
    Focus changed because Key Left/Right/Up/Down was pressed.
    """
    MNEMONIC = 4
    """
    Focus changed because mnemonic key was pressed.
    """
    FORWARD = 16
    """
    Changed Focus to the next control.
    """
    BACKWARD = 32
    """
    Changed Focus to the previous control.
    """
    AROUND = 64
    """
    Changed Focus forward from last to first or backward from first to last.
    """
    UNIQUEMNEMONIC = 256
    """
    Focus changed because mnemonic key was pressed and this mnemonic is unique.
    """

__all__ = ['FocusChangeReason']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.3
from enum import Enum


class TextVerticalAdjust(Enum):
    """
    Enum Class

    

    See Also:
        `API TextVerticalAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a4c2c10f0a1a5fa20d9f200d0fb5707ad>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.TextVerticalAdjust'
    __ooo_type_name__: str = 'enum'

    BLOCK = 'BLOCK'
    """
    The text extends from the left to the right edge of the shape.
    
    The text extends from the top to the bottom edge of the shape.
    """
    BOTTOM = 'BOTTOM'
    """
    the connection line leaves the connected object from the bottom,
    
    The text is positioned below the main line.
    
    The bottom edge of the text is adjusted to the bottom edge of the shape.
    """
    CENTER = 'CENTER'
    """
    The text is centered inside the shape.
    """
    TOP = 'TOP'
    """
    the connection line leaves the connected object from the top,
    
    The text is positioned above the main line.
    
    The top edge of the text is adjusted to the top edge of the shape.
    """

__all__ = ['TextVerticalAdjust']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.awt import FontEmphasisMark as FontEmphasisMark
    if hasattr(FontEmphasisMark, '_constants') and isinstance(FontEmphasisMark._constants, dict):
        FontEmphasisMark._constants['__ooo_ns__'] = 'com.sun.star.awt'
        FontEmphasisMark._constants['__ooo_full_ns__'] = 'com.sun.star.awt.FontEmphasisMark'
        FontEmphasisMark._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global FontEmphasisMarkEnum
        ls = [f for f in dir(FontEmphasisMark) if not callable(getattr(FontEmphasisMark, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(FontEmphasisMark, name)
        FontEmphasisMarkEnum = IntEnum('FontEmphasisMarkEnum', _dict)
    build_enum()
else:
    from ...lo.awt.font_emphasis_mark import FontEmphasisMark as FontEmphasisMark

    class FontEmphasisMarkEnum(IntEnum):
        """
        Enum of Const Class FontEmphasisMark

        These values are used to specify the kind of emphasis mark.
        
        They may be expanded in future versions.
        """
        NONE = FontEmphasisMark.NONE
        """
        specifies no emphasis mark.
        """
        DOT = FontEmphasisMark.DOT
        """
        specifies emphasis mark dot.
        """
        CIRCLE = FontEmphasisMark.CIRCLE
        """
        specifies emphasis mark circle.
        """
        DISC = FontEmphasisMark.DISC
        """
        specifies emphasis mark disc.
        """
        ACCENT = FontEmphasisMark.ACCENT
        """
        specifies emphasis mark accent.
        """
        ABOVE = FontEmphasisMark.ABOVE
        """
        specifies that the emphasis mark should be positioned above the characters.
        """
        BELOW = FontEmphasisMark.BELOW
        """
        specifies that the emphasis mark should be positioned below the characters.
        """

__all__ = ['FontEmphasisMark', 'FontEmphasisMarkEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import uno_enum_class_new
    from com.sun.star.presentation.FadeEffect import (CLOCKWISE, CLOSE_HORIZONTAL, CLOSE_VERTICAL, COUNTERCLOCKWISE, DISSOLVE, FADE_FROM_BOTTOM, FADE_FROM_CENTER, FADE_FROM_LEFT, FADE_FROM_LOWERLEFT, FADE_FROM_LOWERRIGHT, FADE_FROM_RIGHT, FADE_FROM_TOP, FADE_FROM_UPPERLEFT, FADE_FROM_UPPERRIGHT, FADE_TO_CENTER, HORIZONTAL_CHECKERBOARD, HORIZONTAL_LINES, HORIZONTAL_STRIPES, MOVE_FROM_BOTTOM, MOVE_FROM_LEFT, MOVE_FROM_LOWERLEFT, MOVE_FROM_LOWERRIGHT, MOVE_FROM_RIGHT, MOVE_FROM_TOP, MOVE_FROM_UPPERLEFT, MOVE_FROM_UPPERRIGHT, NONE, OPEN_HORIZONTAL, OPEN_VERTICAL, RANDOM, ROLL_FROM_BOTTOM, ROLL_FROM_LEFT, ROLL_FROM_RIGHT, ROLL_FROM_TOP, SPIRALIN_LEFT, SPIRALIN_RIGHT, SPIRALOUT_LEFT, SPIRALOUT_RIGHT, STRETCH_FROM_BOTTOM, STRETCH_FROM_LEFT, STRETCH_FROM_RIGHT, STRETCH_FROM_TOP, UNCOVER_TO_BOTTOM, UNCOVER_TO_LEFT, UNCOVER_TO_LOWERLEFT, UNCOVER_TO_LOWERRIGHT, UNCOVER_TO_RIGHT, UNCOVER_TO_TOP, UNCOVER_TO_UPPERLEFT, UNCOVER_TO_UPPERRIGHT, VERTICAL_CHECKERBOARD, VERTICAL_LINES, VERTICAL_STRIPES, WAVYLINE_FROM_BOTTOM, WAVYLINE_FROM_LEFT, WAVYLINE_FROM_RIGHT, WAVYLINE_FROM_TOP)

    def _get_enum():
        # Dynamically create class that actually contains UNO enum instances
        _dict = {
            "__doc__": "Dynamically created class that represents com.sun.star.presentation.FadeEffect Enum. Class loosly mimics Enum",
            "__new__": uno_enum_class_new,
            "__ooo_ns__": "com.sun.star.presentation",
            "__ooo_full_ns__": "com.sun.star.presentation.FadeEffect",
            "__ooo_type_name__": "enum",
            "CLOCKWISE": CLOCKWISE,
            "CLOSE_HORIZONTAL": CLOSE_HORIZONTAL,
            "CLOSE_VERTICAL": CLOSE_VERTICAL,
            "COUNTERCLOCKWISE": COUNTERCLOCKWISE,
            "DISSOLVE": DISSOLVE,
            "FADE_FROM_BOTTOM": FADE_FROM_BOTTOM,
            "FADE_FROM_CENTER": FADE_FROM_CENTER,
            "FADE_FROM_LEFT": FADE_FROM_LEFT,
            "FADE_FROM_LOWERLEFT": FADE_FROM_LOWERLEFT,
            "FADE_FROM_LOWERRIGHT": FADE_FROM_LOWERRIGHT,
            "FADE_FROM_RIGHT": FADE_FROM_RIGHT,
            "FADE_FROM_TOP": FADE_FROM_TOP,
            "FADE_FROM_UPPERLEFT": FADE_FROM_UPPERLEFT,
            "FADE_FROM_UPPERRIGHT": FADE_FROM_UPPERRIGHT,
            "FADE_TO_CENTER": FADE_TO_CENTER,
            "HORIZONTAL_CHECKERBOARD": HORIZONTAL_CHECKERBOARD,
            "HORIZONTAL_LINES": HORIZONTAL_LINES,
            "HORIZONTAL_STRIPES": HORIZONTAL_STRIPES,
            "MOVE_FROM_BOTTOM": MOVE_FROM_BOTTOM,
            "MOVE_FROM_LEFT": MOVE_FROM_LEFT,
            "MOVE_FROM_LOWERLEFT": MOVE_FROM_LOWERLEFT,
            "MOVE_FROM_LOWERRIGHT": MOVE_FROM_LOWERRIGHT,
            "MOVE_FROM_RIGHT": MOVE_FROM_RIGHT,
            "MOVE_FROM_TOP": MOVE_FROM_TOP,
            "MOVE_FROM_UPPERLEFT": MOVE_FROM_UPPERLEFT,
            "MOVE_FROM_UPPERRIGHT": MOVE_FROM_UPPERRIGHT,
            "NONE": NONE,
            "OPEN_HORIZONTAL": OPEN_HORIZONTAL,
            "OPEN_VERTICAL": OPEN_VERTICAL,
            "RANDOM": RANDOM,
            "ROLL_FROM_BOTTOM": ROLL_FROM_BOTTOM,
            "ROLL_FROM_LEFT": ROLL_FROM_LEFT,
            "ROLL_FROM_RIGHT": ROLL_FROM_RIGHT,
            "ROLL_FROM_TOP": ROLL_FROM_TOP,
            "SPIRALIN_LEFT": SPIRALIN_LEFT,
            "SPIRALIN_RIGHT": SPIRALIN_RIGHT,
            "SPIRALOUT_LEFT": SPIRALOUT_LEFT,
            "SPIRALOUT_RIGHT": SPIRALOUT_RIGHT,
            "STRETCH_FROM_BOTTOM": STRETCH_FROM_BOTTOM,
            "STRETCH_FROM_LEFT": STRETCH_FROM_LEFT,
            "STRETCH_FROM_RIGHT": STRETCH_FROM_RIGHT,
            "STRETCH_FROM_TOP": STRETCH_FROM_TOP,
            "UNCOVER_TO_BOTTOM": UNCOVER_TO_BOTTOM,
            "UNCOVER_TO_LEFT": UNCOVER_TO_LEFT,
            "UNCOVER_TO_LOWERLEFT": UNCOVER_TO_LOWERLEFT,
            "UNCOVER_TO_LOWERRIGHT": UNCOVER_TO_LOWERRIGHT,
            "UNCOVER_TO_RIGHT": UNCOVER_TO_RIGHT,
            "UNCOVER_TO_TOP": UNCOVER_TO_TOP,
            "UNCOVER_TO_UPPERLEFT": UNCOVER_TO_UPPERLEFT,
            "UNCOVER_TO_UPPERRIGHT": UNCOVER_TO_UPPERRIGHT,
            "VERTICAL_CHECKERBOARD": VERTICAL_CHECKERBOARD,
            "VERTICAL_LINES": VERTICAL_LINES,
            "VERTICAL_STRIPES": VERTICAL_STRIPES,
            "WAVYLINE_FROM_BOTTOM": WAVYLINE_FROM_BOTTOM,
            "WAVYLINE_FROM_LEFT": WAVYLINE_FROM_LEFT,
            "WAVYLINE_FROM_RIGHT": WAVYLINE_FROM_RIGHT,
            "WAVYLINE_FROM_TOP": WAVYLINE_FROM_TOP,
        }
        result = type('FadeEffect', (object,), _dict)
        return result

    FadeEffect = _get_enum()
else:
    from ...lo.presentation.fade_effect import FadeEffect as FadeEffect

__all__ = ['FadeEffect']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.office
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_annotation import XAnnotation as XAnnotation_bb8f0be7

class XAnnotationEnumeration(ABC):
    """
    An enumeration for a set of annotations.

    See Also:
        `API XAnnotationEnumeration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotationEnumeration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.office'
    __ooo_full_ns__: str = 'com.sun.star.office.XAnnotationEnumeration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.office.XAnnotationEnumeration'

    @abstractmethod
    def hasMoreElements(self) -> bool:
        """
        tests whether this enumeration contains more elements.
        """
    @abstractmethod
    def nextElement(self) -> 'XAnnotation_bb8f0be7':
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """

__all__ = ['XAnnotationEnumeration']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XSheetConditionalEntries(XIndexAccess_f0910d6d):
    """
    provides methods to add and remove conditions of a conditional format.

    See Also:
        `API XSheetConditionalEntries <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntries.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetConditionalEntries'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetConditionalEntries'

    @abstractmethod
    def addNew(self, aConditionalEntry: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        adds a conditional entry to the format.
        
        Supported properties are:
        """
    @abstractmethod
    def clear(self) -> None:
        """
        clears all condition entries.
        """
    @abstractmethod
    def removeByIndex(self, nIndex: int) -> None:
        """
        removes a conditional entry from the format.
        """

__all__ = ['XSheetConditionalEntries']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from abc import abstractproperty
from .base_index import BaseIndex as BaseIndex_8f0d0a40

class ObjectIndex(BaseIndex_8f0d0a40):
    """
    Service Class

    specifies service of object indexes within a document.

    See Also:
        `API ObjectIndex <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1ObjectIndex.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.ObjectIndex'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CreateFromOtherEmbeddedObjects(self) -> bool:
        """
        Determines if external embedded objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarCalc(self) -> bool:
        """
        Determines if star office calc objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarChart(self) -> bool:
        """
        Determines if star office chart objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarDraw(self) -> bool:
        """
        Determines if star office draw objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarImage(self) -> bool:
        """
        Determines if star office image objects are included in the office.
        """

    @abstractproperty
    def CreateFromStarMath(self) -> bool:
        """
        Determines if star office math objects are included in the office.
        """



__all__ = ['ObjectIndex']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.text import ControlCharacter as ControlCharacter
    if hasattr(ControlCharacter, '_constants') and isinstance(ControlCharacter._constants, dict):
        ControlCharacter._constants['__ooo_ns__'] = 'com.sun.star.text'
        ControlCharacter._constants['__ooo_full_ns__'] = 'com.sun.star.text.ControlCharacter'
        ControlCharacter._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global ControlCharacterEnum
        ls = [f for f in dir(ControlCharacter) if not callable(getattr(ControlCharacter, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(ControlCharacter, name)
        ControlCharacterEnum = IntEnum('ControlCharacterEnum', _dict)
    build_enum()
else:
    from ...lo.text.control_character import ControlCharacter as ControlCharacter

    class ControlCharacterEnum(IntEnum):
        """
        Enum of Const Class ControlCharacter

        These constants are the codes for inserting control characters using XSimpleText.insertControlCharacter() interface.
        """
        PARAGRAPH_BREAK = ControlCharacter.PARAGRAPH_BREAK
        """
        This control character starts a new paragraph.
        """
        LINE_BREAK = ControlCharacter.LINE_BREAK
        """
        This control character starts a new line in a paragraph.
        """
        HARD_HYPHEN = ControlCharacter.HARD_HYPHEN
        """
        This control character equals a dash but prevents this position from being hyphenated.
        """
        SOFT_HYPHEN = ControlCharacter.SOFT_HYPHEN
        """
        This control character defines a special position as a hyphenation point.
        
        If a word containing a soft hyphen must be split at the end of a line, then this position is preferred.
        """
        HARD_SPACE = ControlCharacter.HARD_SPACE
        """
        This control character is used to link two words and prevents this concatenation from being hyphenated.
        
        It is printed as a space.
        """
        APPEND_PARAGRAPH = ControlCharacter.APPEND_PARAGRAPH
        """
        This control character appends a new paragraph.
        """

__all__ = ['ControlCharacter', 'ControlCharacterEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.configuration
# Libre Office Version: 7.3
from ooo.oenv.env_const import UNO_NONE
import typing
from .cannot_load_configuration_exception import CannotLoadConfigurationException as CannotLoadConfigurationException_b325176a
from ..uno.x_interface import XInterface as XInterface_8f010a43

class MissingBootstrapFileException(CannotLoadConfigurationException_b325176a):
    """
    Exception Class

    is thrown when creating a configuration provider fails because a bootstrap file needed to locate the configuration is missing

    See Also:
        `API MissingBootstrapFileException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1configuration_1_1MissingBootstrapFileException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.configuration'
    __ooo_full_ns__: str = 'com.sun.star.configuration.MissingBootstrapFileException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.configuration.MissingBootstrapFileException'
    __pyunostruct__: str = 'com.sun.star.configuration.MissingBootstrapFileException'

    typeName: str = 'com.sun.star.configuration.MissingBootstrapFileException'
    """Literal Constant ``com.sun.star.configuration.MissingBootstrapFileException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, BootstrapFileURL: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            BootstrapFileURL (str, optional): BootstrapFileURL value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "BootstrapFileURL": BootstrapFileURL,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._bootstrap_file_url = kwargs["BootstrapFileURL"]
        inst_keys = ('BootstrapFileURL',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def BootstrapFileURL(self) -> str:
        """
        the URL of the bootstrap file that could not be found
        """
        return self._bootstrap_file_url
    
    @BootstrapFileURL.setter
    def BootstrapFileURL(self, value: str) -> None:
        self._bootstrap_file_url = value


__all__ = ['MissingBootstrapFileException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME
_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from com.sun.star.rendering import PanoseMidline as PanoseMidline
    if hasattr(PanoseMidline, '_constants') and isinstance(PanoseMidline._constants, dict):
        PanoseMidline._constants['__ooo_ns__'] = 'com.sun.star.rendering'
        PanoseMidline._constants['__ooo_full_ns__'] = 'com.sun.star.rendering.PanoseMidline'
        PanoseMidline._constants['__ooo_type_name__'] = 'const'
    def build_enum():
        global PanoseMidlineEnum
        ls = [f for f in dir(PanoseMidline) if not callable(getattr(PanoseMidline, f)) and not f.startswith('__')]
        _dict = {}
        for name in ls:
            _dict[name] = getattr(PanoseMidline, name)
        PanoseMidlineEnum = IntEnum('PanoseMidlineEnum', _dict)
    build_enum()
else:
    from ...lo.rendering.panose_midline import PanoseMidline as PanoseMidline

    class PanoseMidlineEnum(IntEnum):
        """
        Enum of Const Class PanoseMidline

        """
        ANYTHING = PanoseMidline.ANYTHING
        NO_FIT = PanoseMidline.NO_FIT
        STANDARD_TRIMMED = PanoseMidline.STANDARD_TRIMMED
        STANDARD_POINTED = PanoseMidline.STANDARD_POINTED
        STANDARD_SERIFED = PanoseMidline.STANDARD_SERIFED
        HIGH_TRIMMER = PanoseMidline.HIGH_TRIMMER
        HIGH_POINTED = PanoseMidline.HIGH_POINTED
        HIGH_SERIFED = PanoseMidline.HIGH_SERIFED
        CONSTANT_TRIMMED = PanoseMidline.CONSTANT_TRIMMED
        CONSTANT_POINTED = PanoseMidline.CONSTANT_POINTED
        CONSTANT_SERIFED = PanoseMidline.CONSTANT_SERIFED
        LOW_TRIMMED = PanoseMidline.LOW_TRIMMED
        LOW_POINTED = PanoseMidline.LOW_POINTED
        LOW_SERIFED = PanoseMidline.LOW_SERIFED

__all__ = ['PanoseMidline', 'PanoseMidlineEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6

class XDecks(XIndexAccess_f0910d6d, XNameAccess_e2ab0cf6):
    """
    provides access to Decks of a Sidebar.
    
    **since**
    
        LibreOffice 5.1

    See Also:
        `API XDecks <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XDecks.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XDecks'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XDecks'


__all__ = ['XDecks']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.view
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_selection_change_listener import XSelectionChangeListener as XSelectionChangeListener_58bf104d

class XSelectionSupplier(XInterface_8f010a43):
    """
    makes it possible to access and change the selection in a view.

    See Also:
        `API XSelectionSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XSelectionSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XSelectionSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XSelectionSupplier'

    @abstractmethod
    def addSelectionChangeListener(self, xListener: 'XSelectionChangeListener_58bf104d') -> None:
        """
        registers an event listener, which is called when the selection changes.
        """
    @abstractmethod
    def getSelection(self) -> object:
        """
        The selection is either specified by an object which is contained in the component to which the view belongs, or it is an interface of a collection which contains such objects.
        """
    @abstractmethod
    def removeSelectionChangeListener(self, xListener: 'XSelectionChangeListener_58bf104d') -> None:
        """
        unregisters an event listener which was registered with XSelectionSupplier.addSelectionChangeListener().
        """
    @abstractmethod
    def select(self, xSelection: object) -> bool:
        """
        selects the object represented by xSelection if it is known and selectable in this object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """

__all__ = ['XSelectionSupplier']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from abc import abstractmethod
from .x_component_supplier import XComponentSupplier as XComponentSupplier_adb0e64

class XEmbeddedClient(XComponentSupplier_adb0e64):
    """
    represents common functionality for embedded clients.

    See Also:
        `API XEmbeddedClient <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbeddedClient.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XEmbeddedClient'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XEmbeddedClient'

    @abstractmethod
    def saveObject(self) -> None:
        """
        asks client to let the object store itself.

        Raises:
            com.sun.star.embed.ObjectSaveVetoException: ``ObjectSaveVetoException``
            com.sun.star.uno.Exception: ``Exception``
        """
    @abstractmethod
    def visibilityChanged(self, bVisible: bool) -> None:
        """
        An object can use this method to notify the client when the object outplace window becomes visible or invisible.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """

__all__ = ['XEmbeddedClient']

